@@ -13,8 +13,8 @@
 package Config::Validator;
 use strict;
 use warnings;
-our $VERSION  = "1.2";
-our $REVISION = sprintf("%d.%02d", q$Revision: 1.35 $ =~ /(\d+)\.(\d+)/);
+our $VERSION  = "1.3";
+our $REVISION = sprintf("%d.%02d", q$Revision: 1.36 $ =~ /(\d+)\.(\d+)/);
 
 #
 # used modules
@@ -430,7 +430,9 @@ sub _options ($$$@) {
     return(join("-", @path) . "!")  if $type eq "boolean";
     # assumed to come from strings
     return(join("-", @path) . "=s")
-        if $type =~ /^isa\(.+\)$/ or $type eq "table(string)";
+        if $type =~ /^isa\(.+\)$/
+        or $type eq "table(string)"
+        or $type =~ /^(duration|hostname|ipv[46]|regexp|size)$/;
     # recursion
     if ($type =~ /^list\?\((.+)\)$/) {
         return(map($_ . "\@", _options($valid, $schema, $1, @path)));
@@ -1517,4 +1519,4 @@ the possibilities of this module.
 
 Lionel Cons L<http://cern.ch/lionel.cons>
 
-Copyright (C) CERN 2012-2014
+Copyright (C) CERN 2012-2015
